@@ -1,4 +1,5 @@
-panelcontour <- function(x, y, ...)
+panelcontour <-
+function(x, y, ...)
 {
      usr <- par("usr"); on.exit(par(usr))
      par(usr = c(usr[1:2], 0, 1.5) )
@@ -7,3 +8,4 @@ panelcontour <- function(x, y, ...)
      #points(x,y,col="light grey")
      contour(kd,add=TRUE,drawlabels=FALSE,levels=c(kdmax*0.01,kdmax*0.5,kdmax*0.9),col=c("red","blue","green"),...)
 }
+
